var express = require('express')
  , passport = require('passport')
  , util = require('util')
  , _500pxStrategy = require('passport-500px').Strategy;

var _5OOpx_APP_ID = "rKU9vjaGZ4LqgjBDv1wB3ridMUuXnQjrN4iBUEMX"
  , _5OOpx_APP_SECRET = "--insert-500px-consumer-secret-here--";

// Passport session setup.
//   To support persistent login sessions, Passport needs to be able to
//   serialize users into and deserialize users out of the session.  Typically,
//   this will be as simple as storing the user ID when serializing, and finding
//   the user by ID when deserializing.  However, since this example does not
//   have a database of user records, the complete 500px profile is
//   serialized and deserialized.
passport.serializeUser(function(user, done) {
  done(null, user);
});

passport.deserializeUser(function(obj, done) {
  done(null, obj);
});


// Use the _500pxStrategy within Passport.
//   Strategies in passport require a `verify` function, which accept
//   credentials (in this case, a token, tokenSecret, and 500px profile), and
//   invoke a callback with a user object.
passport.use(new _500pxStrategy({
    consumerKey: _5OOpx_APP_ID,
    consumerSecret: _5OOpx_APP_SECRET,
    callbackURL: "http://localhost:3000/auth/500px/callback"
  },
  function(token, tokenSecret, profile, done) {
    // asynchronous verification, for effect...
    process.nextTick(function () {
      
      // To keep the example simple, the user's 500px profile is returned to
      // represent the logged-in user.  In a typical application, you would want
      // to associate the 500px account with a user record in your database,
      // and return that user instead.
      return done(null, profile);
    });
  }
));




var app = express.createServer();

// configure Express
app.configure(function() {
  app.set('views', __dirname + '/views');
  app.set('view engine', 'ejs');
  app.use(express.logger());
  app.use(express.cookieParser());
  app.use(express.bodyParser());
  app.use(express.methodOverride());
  app.use(express.session({ secret: 'keyboard cat' }));
  // Initialize Passport!  Also use passport.session() middleware, to support
  // persistent login sessions (recommended).
  app.use(passport.initialize());
  app.use(passport.session());
  app.use(app.router);
  app.use(express.static(__dirname + '/public'));
});


app.get('/', function(req, res){
  res.render('index', { user: req.user });
});

app.get('/account', ensureAuthenticated, function(req, res){
  res.render('account', { user: req.user });
});

app.get('/login', function(req, res){
  res.render('login', { user: req.user });
});

// GET /auth/500px
//   Use passport.authenticate() as route middleware to authenticate the
//   request.  The first step in 500px authentication will involve redirecting
//   the user to 500px.com.  After authorization, 500px will redirect the user
//   back to this application at /auth/500px/callback
app.get('/auth/500px',
  passport.authenticate('500px'),
  function(req, res){
    // The request will be redirected to 500px for authentication, so this
    // function will not be called.
  });

// GET /auth/500px/callback
//   Use passport.authenticate() as route middleware to authenticate the
//   request.  If authentication fails, the user will be redirected back to the
//   login page.  Otherwise, the primary route function function will be called,
//   which, in this example, will redirect the user to the home page.
app.get('/auth/500px/callback', 
  passport.authenticate('500px', { failureRedirect: '/login' }),
  function(req, res) {
    res.redirect('/');
  });

app.get('/logout', function(req, res){
  req.logout();
  res.redirect('/');
});

app.listen(3000);


// Simple route middleware to ensure user is authenticated.
//   Use this route middleware on any resource that needs to be protected.  If
//   the request is authenticated (typically via a persistent login session),
//   the request will proceed.  Otherwise, the user will be redirected to the
//   login page.
function ensureAuthenticated(req, res, next) {
  if (req.isAuthenticated()) { return next(); }
  res.redirect('/login')
}
